SUPPORTED_MODELS = {
    "openai": [
        # GPT-5 Series (Flagship Reasoning Models - 2026)
        "gpt-5.2",
        "gpt-5.2-pro",
        "gpt-5.2-chat",
        "gpt-5.2-codex",
        "gpt-5.1",
        "gpt-5.1-codex",
        "gpt-5.1-codex-mini",
        "gpt-5",
        "gpt-5-nano",
        # GPT-5.3 Codex Series
        "gpt-5.3-codex",
        "gpt-5.3-codex-spark",
        # GPT-4.1 Series
        "gpt-4.1",
        "gpt-4.1-mini",
        "gpt-4.1-nano",
    ],
    "azure_openai": [
        # GPT-5 Family (require registration)
        "gpt-5.2",
        "gpt-5.2-codex",
        "gpt-5.1",
        "gpt-5.1-codex",
        "gpt-5.1-codex-max",
        "gpt-5",
        "gpt-5-mini",
        "gpt-5-nano",
        "gpt-5-chat",
        # GPT-4.1 Family
        "gpt-4.1",
        "gpt-4.1-mini",
        "gpt-4.1-nano",
        # GPT-4o Family (multimodal)
        "gpt-4o",
        "gpt-4o-mini",
        # Image & Audio
        "gpt-image-1.5",
        "gpt-4o-transcribe-mini",
    ],
    "vertex": [
        # Gemini 3 Series (Latest - 2026)
        "gemini-3-pro",
        "gemini-3-flash",
        # Gemini 2.5 Series (Stable Production)
        "gemini-2.5-pro",
        "gemini-2.5-flash",
        "gemini-2.5-flash-lite",
    ],
    "ollama": [],
    "openrouter": [
        # OpenAI models
        "openai/gpt-5.2",
        "openai/gpt-5.1",
        "openai/gpt-5",
        # Google models
        "google/gemini-3-pro",
        "google/gemini-3-flash",
        "google/gemini-2.5-pro",
        "google/gemini-2.5-flash",
        # Anthropic models
        "anthropic/claude-sonnet-4.6",
        "anthropic/claude-opus-4.6",
        "anthropic/claude-opus-4.5",
        "anthropic/claude-haiku-4.5",
        # DeepSeek models
        "deepseek/deepseek-v3.1",
        "deepseek/deepseek-r1",
        # Meta models
        "meta-llama/llama-3.3-70b-instruct",
        "meta-llama/llama-4-maverick-17b-128e-instruct",
        # Other
        "qwen/qwen-2.5-72b-instruct",
    ],
    "anthropic": [
        # Claude 4 Series (Latest - February 2026)
        "claude-sonnet-4.6",
        "claude-opus-4.6",
        "claude-opus-4.5",
        "claude-haiku-4.5",
    ],
    "gemini": [
        # Gemini 3 Series (via Google AI Studio)
        "gemini-3-pro",
        "gemini-3-flash",
        "gemini-3-pro-image",
        # Gemini 2.5 Series (Stable)
        "gemini-2.5-pro",
        "gemini-2.5-flash",
        "gemini-2.5-flash-lite",
    ],
}
